!     Last change: ZK 3/6/2020 1:20:20 PM

      PROGRAM WAVE
!program originated by ZK, tested and corrected by BK
!  Computations are based on section 9 chapI
!  This program compares certain parameters of
!  surface and internal waves of the same period

!  The period T1 is given in hours, the depth of
!  upper H1 and lower H2 layers is defined in meters
!  the density in the upper layer RH1 and density
!  in the lower layer RH2 are in g/cm^3
!  all computations are done in CGS

!  Out of these data first the phase speed of the
!  external(barotropic)mode is computed as CE1 and
!  next the influence of the density stratification on the
!  same speed is calculate as CGE. The internal phase speed is
!  defined by CI. To compare properties of external\internal
!  waves the wave length LAMI, and LAME as well internal RRDI
!  and external RRDE Rosby numbers are given. Also since the internal
!  wave height at the internal surface (Z2) is defined from input
!  the interal wave amplitude at the free surface surface (Z1)
!  and the particle velocity in the internal wave in the upper layer
!  V1 and in lower layer V2 are computed. Finally to see the influence of density
!  on travel time the length of the "ocean" L is given
!  and phase speeds CE1 and CGS are used to evaluate the travel time difference

      IMPLICIT NONE
      INTEGER,PARAMETER :: DP=SELECTED_REAL_KIND(15)
!      INTEGER,PARAMETER::DPI=SELECTED_INT_KIND(8)
      REAL(KIND=DP), PARAMETER :: G=981._dp
!      REAL(KIND=DP), PARAMETER:: PI=3.141592653589793238462643383279502884197_DP
      REAL(KIND=DP), PARAMETER :: RAD= 0.0174532930056254

      REAL(KIND=DP), PARAMETER :: ROT=7.2919E-5  ! EARTH'S ROTATION
      REAL(KIND=DP) :: TW1S, T1, H1, H2, RH1, RH2
      REAL(KIND=DP) :: TE1, TE2, L, DIFF
      REAL(KIND=DP) :: DENS, DEPTH, DEPTH2, CI, RRDE, RRDI, CGP1, CGE
      REAL(KIND=DP) :: V2, V1, Z2, Z1, DEPTH1, CE1, CE2, LAMI, LAME, COR, PHI


! read in parameter
      print*,"read period T1 in hours"
      READ*,T1
      TW1S = T1*3600._dp                  !change into seconds

      PRINT*,"READ DEPTH OF THE LAYER H1,H2 IN M   "
      READ*,H1,H2
      PRINT*,"READ DENSITy OF THE UPPER AND LOWER LAYER IN G/CM3   "
      READ*,RH1,RH2

      H1 = H1*100._dp  !change into centimeters
      H2 = H2*100._dp
      PRINT*,"READ INTERNAL WAVE AMPLITUDE IN M  "
      READ*,Z2
      Z2 = Z2*100._dp
      PRINT*,"READ LATITUDE IN DEGREE"
      READ*,PHI
      PHI = RAD*PHI
      COR = 2._dp*ROT*SIN(PHI)
      print*,"read ocean lenth in km"
      READ*,L
      L=L*1000._dp    !in meter

! INTERNAL/EXTERNAL  WAVE COMPUTATION
      CE1 = SQRT((h1+H2)*G)                      !phase velocity for external  wave
      DENS = (RH2-RH1)/RH2
      DEPTH1 = H2/(H1+H2)
      DEPTH = H1* DEPTH1
      DEPTH2 = H1*H2/((H1+H2)*(H1+H2))
      CE2 = SQRT((h1+H2)*G*(1._DP-DEPTH2*dens))  !SHORT FORMULA FOR EXT  VEL+DENS
      CGP1 = 1._DP+SQRT(1._DP-4._DP*DENS*DEPTH2)
      CGE = SQRT(G*(H1+H2)*CGP1/2._DP)           !FULL FORMULA FOR EXT  VEL+DENS

      CI = SQRT(DENS*G*DEPTH)                    !phase velocity for internal wave
      v2 = CI*Z2/H2                              !particle velocity in lower layer
      V1 = -V2*H2/H1                             !particle velocity in upper layer

      Z1 = -DENS*DEPTH1*Z2                       !surface amplitude due  to internal wave
      LAMI = CI*TW1S                             !internal wave wavelength
      LAME = CE1*TW1S                            !external wave wavelength
      RRDE = CE1/COR                             !external Rossby number
      RRDI = CI/COR                              !internal Rossby number

!ocean lenth of L=10000km
! What is time difference for travel with ce1 and ce2
      TE1 = L*100._dp/ce1
      TE2 = L*100._dp/cge
      DIFF = TE2-TE1

      PRINT*,"PHASE VELOCITY external  IN M/SEC)=",CE1/100._dp
      PRINT*,"PHASE VELOCITY external With DENSITY CORRECTION  IN M/SEC)=",CE2/100._dp
      PRINT*,"PHASE VELOCITY GENERAL external  IN M/SEC)=",CGE/100._dp
      PRINT*,"PHASE VELOCITY, internal IN CM/SEC)=",CI
      PRINT*,"PARTICLE VELOCITY IN LOWER LAYER in cm/s=",V2
      PRINT*,"PARTICLE VELOCITY IN UPPER LAYERin cm/s=",V1
      PRINT*,"AMPLTUDE AT FREE SURFACE in cm=",Z1
      PRINT*," amplitude at internal SURFACE in m=",Z2/100._dp
      PRINT*,"INTERNAL WAVE LENGTH IN KM=",LAMI/1E5
      PRINT*,"ENTERNAL WAVE LENGTH  IN KM=",LAME/1.E5
      PRINT*,"PERIOD IN HOURS=",T1
      PRINT*,"INTERNAL ROSSBY RADIUS IN KM=", RRDI/1.E5
      PRINT*,"EXTERNAL ROSSBY RADIUS IN KM=", RRDE/1.E5
      PRINT*,"TIME TRAVEL for TE1 in hours=",TE1/3600.
      PRINT*,"TIME TRAVEL for TE2 in hours=",TE2/3600.

      PRINT*,"RELATIVE DENSITY=",DENS
      PRINT*,"CORIOLIS PARAMETER=  ", COR
      WRITE (*,'(//,(30X,A))')'INPUT DATA'

      WRITE (*,'(/,2(3X,A,F8.1))')' DEPTH UPPER LAYER H1 (M)=',H1/100.,' DEPTH  LOWER LAYER H2 (M)=',H2/100.
      WRITE (*,'(/,2(1X,A,F6.3))')'DENSITY UPPER LAYER RH1(G/CM^3)=',RH1,'DENSITY LOWER LAYER RH2(G/CM^3)=',RH2
      WRITE (*,'(/,2(1X,A,F10.1))')'INTERNAL WAVE AMPLITUDE Z2(M)=',Z2/100.,'Wave period  in seconds=',T1*3600.
      WRITE (*,'(/,2(1X,A,F10.1))')'LATITUDE IN DEGREE=',PHI/rad,'OCEAN LENGTH IN KM',L/1000.

!      WRITE (*,'(/)')  !vertical space
      WRITE (*,'(//,(20X,A))')'COMPARISON EXTERNAL VS INTERNAL WAVES'

      WRITE (*,'(/,2(3X,A,F6.1))')'EXTERNAL PHASE VELOCITY (M/S)',CGE/100.,'INTERNAL PHASE VELOCITY(M/S)',CI/100.
      WRITE (*,'(/,2(3X,A,F7.1))')'EXTERNAL WAVELENGTH (KM)',LAME/1.E5,'INTERNAL WAVELENGTH(KM)',LAMI/1E5
      WRITE (*,'(/,2(3X,A,F7.1))')'EXTERNAL ROSBY RADIUS (KM)',RRDE/1.E5,'INTERNAL ROSBY RADIUS(KM)',RRDI/1E5

      WRITE (*,'(//,(20X,A))')' ADDITIONAL PARAMETERS OF INTERNAL WAVES'

      WRITE (*,'(/,2(3X,A,F7.3))')' VELOCITY IN UPPER LAYER (M/S)',V1/100.,'VELOCITY IN LOWER LAYER (M/S)',V2/100.
      WRITE (*,'(/,2(3X,A,F7.3))')' AMPLITUDE AT H1 DEPTHT(M)',Z2/100.,'AMPLITUDE AT FREE SURFACE (M)',Z1/100.

      WRITE (*,'(//,(15X,A,F10.1))')' TIME TO TRAVEL OVER THE OCEAN WITH LENGHT (KM)',L/1000.

      WRITE (*,'(/,2(3X,A,F8.4))')' FOR VELOCITY CGE (HOUR)',TE2/3600.,' FOR  VELOCITY CE1 (HOUR))',TE1/3600.
      WRITE (*,'(/,(15X,A,F10.3))')' TIME DIFFERENCE TE2-TE1 IN SECONDS',DIFF


 !==========================================
      END Program WAVE

