!     Last change: ZK 3/6/2020 1:22:50 PM

      PROGRAM WAVELENGTH
! program originated by ZK, corrected and tested by BK
!       Computation are based on section 12 chapI
!       PROGRAM  computes certain parameters of
!       surface  waves when period (T)and water depth (H)
!       are pescribed.
!       all computations done in MKS units
!       First by using iterational  approach the
!       wavelength is computed  LAMBDA_OLD
!       SUBSEQUENTLY PHASE AND GROUP VELOCITIES ARE
!       CALCULATED: CPHASE,CGROUP

      IMPLICIT NONE
      INTEGER, PARAMETER :: DP=SELECTED_REAL_KIND(15)
      REAL(KIND=DP), PARAMETER :: G=9.81_dp
      INTEGER :: I
      REAL(KIND=DP) :: T, H, PPI, CPHASE, CGROUP, C1, C2, C3, PI
      REAL(KIND=DP) :: LAMBDA_OLD, LAMBDA_NEW, LAMS, LAML, S1, S2, LDIF

      PI = 4._DP*ATAN(1._DP)
      PPI= PI*2._DP
!     PRINT*,"PPI=",PPI

      print*,"read period T in sec"
      READ*,T


      PRINT*,"READ DEPTH H IN M   "
      READ*,H

!     LAM=T*SQRT((G*LAM /2PI)TANH(2*PI*H/LAM)) !EXACT FORMULA
!     LAMS=GT^2/(2PI) !SHORT WAVE APPROXIMATION
!     LAML=TSQRT(GH)  !LONG WAVE WAVE APPROXIMATION

!     START ITERATION LOOP
!     INITIAL WAVELENGTH LENGTH LAMBDA_old=0.5*(LAMS+LAML)
      LAMS = G*T*T/PPI
      LAML = T *SQRT(G*H)
      LAMBDA_OLD = (LAMS+LAML)*0.5_DP   !this is the initial "guess" for the correct wavelength

      DO i = 1,100    !iteration loop
        S1 = PPI*H/LAMBDA_OLD
        S2 = G*LAMBDA_OLD/PPI
        LAMBDA_NEW = T*SQRT(S2*TANH(S1))
        LDIF = ABS(LAMBDA_OLD-LAMBDA_NEW)
        IF (LDIF.LT.0.001) GO TO 100
        LAMBDA_OLD = LAMBDA_NEW
      END DO

  100 CONTINUE
      CPHASE = (G*T/PPI)*TANH(PPI*H/LAMBDA_OLD) !PHASE VELOCITY
      C1 = LAMBDA_OLD/(T*2._DP)
      C2 = H*PPI*2._DP/LAMBDA_OLD
      C3 = 1._DP+C2/SINH(C2)
      CGROUP = C1*C3  !GROUP VELOCITY
      PRINT*,"NUMBER OF ITERATION TO CONVERGE = ",I

      WRITE (*,'(///,2(5X,A,F8.2))')'DEPTH IN METERS=',H,'WAVE PERIOD IN SEC=',T
      WRITE (*,'(/)')  !vertical space
      WRITE (*,'(//2(5X,A,F12.2))')'WAVELENGTH(M)=',LAMBDA_OLD, 'WAVELENGTH(KM)=',LAMBDA_OLD/1000.
      WRITE (*,'(//,2(5X,A,F8.2))')'PHASE VEL(M/SEC)=',CPHASE,' GROUP VEL(M/SEC)=',CGROUP

!     WRITE(LAMBDA_OLD,F10.3)

      END program WAVELENGTH

